==> kogito-api-incubation-common-1.14.0.Final-test-sources.jar: org/kie/kogito/incubation/common/DataContexts.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.incubation.common;

import java.util.Objects;

class Address {
    String street;

    @Override
    public boolean equals(Object o) {
        return (o instanceof Address)
                && Objects.equals(((Address) o).street, street);
    }

}

class User implements DataContext, DefaultCastable {
    String firstName;
    String lastName;
    Address addr;

    @Override
    public boolean equals(Object o) {
        if (o instanceof User) {
            User user = (User) o;
            return Objects.equals(firstName, user.firstName)
                    && Objects.equals(lastName, user.lastName)
                    && Objects.equals(addr, user.addr);
        } else
            return false;
    }

    @Override
    public int hashCode() {
        return Objects.hash(firstName, lastName, addr);
    }
}

class CustomMeta implements MetaDataContext {
    String value;

    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        CustomMeta that = (CustomMeta) o;
        return Objects.equals(value, that.value);
    }

    @Override
    public int hashCode() {
        return Objects.hash(value);
    }
}

==> kogito-api-incubation-common-1.19.0.Final-test-sources.jar: org/kie/kogito/incubation/common/DataContexts.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.incubation.common;

import java.util.Objects;

class Address {
    String street;

    @Override
    public boolean equals(Object o) {
        return (o instanceof Address)
                && Objects.equals(((Address) o).street, street);
    }

}

class User implements DataContext, DefaultCastable {
    String firstName;
    String lastName;
    Address addr;

    @Override
    public boolean equals(Object o) {
        if (o instanceof User) {
            User user = (User) o;
            return Objects.equals(firstName, user.firstName)
                    && Objects.equals(lastName, user.lastName)
                    && Objects.equals(addr, user.addr);
        } else
            return false;
    }

    @Override
    public int hashCode() {
        return Objects.hash(firstName, lastName, addr);
    }
}

class CustomMeta implements MetaDataContext, DefaultCastable {
    String value;

    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        CustomMeta that = (CustomMeta) o;
        return Objects.equals(value, that.value);
    }

    @Override
    public int hashCode() {
        return Objects.hash(value);
    }
}
